@@ -44,7 +44,7 @@ class ScalarIndicatorsCommand(BasicCommand):
         indicator = Indicator(fields["indicator_name"],
                               fields["formula"],
                               None,
-                              fields.get("processors_selector"),
+                              fields.get("processors_selector"),  # Not gathered from worksheet
                               benchmarks,
                               IndicatorCategories.factors_expression if strcmp(fields.get("local"), "Yes")
                               else IndicatorCategories.case_study,
