@@ -2,8 +2,6 @@
 import ast
 import base64
 import collections
-import functools
-import gzip
 import io
 import itertools
 import json
@@ -25,9 +23,6 @@ import jsonpickle
 import numpy as np
 import pandas as pd
 import pycurl
-import requests
-import webdav.client as wc
-from flask import after_this_request, request
 from multidict import MultiDict, CIMultiDict
 from pandas import DataFrame
 
@@ -506,6 +501,20 @@ df.loc[("h", slice(None)), "c"]
 
 
 class PartialRetrievalDictionary:
+    """
+    A (k, v) storage where "k" is Dict of (str, str) and "v" is an object:
+
+    reg = PartialRetrievalDictionary()
+    reg.put(dict(a="1", b="3"), [4, 5, 9])
+
+    The retrieval method, "get", is passed a partial key also in the form of a Dict of (str, str) and returns a list
+    of objects matching the partial key:
+
+    reg.get(dict(a="1")) -> [[4, 5, 9]]
+
+    NOTE: when inserting, both "k" and "v" (object) should be unique
+
+    """
     def __init__(self):
         # A dictionary of key-name to dictionaries, where the dictionaries are each of the values of the key and the
         # value is a set of IDs having that value
@@ -591,7 +600,7 @@ class PartialRetrievalDictionary:
             d = self._keys.get(k, {})
             if len(d) == 0:
                 self._keys[k] = d
-            if v not in d:
+            if v not in d:  # A new value "v" for subkey "k"
                 not_present.append((d, v))
             else:
                 present.append(d.get(v))
@@ -621,10 +630,13 @@ class PartialRetrievalDictionary:
                 self._rev_objs[value] = oid
 
             # Insert
+
+            # Add the subkey value to the subkey dictionaries where it is not present
             for d, v in not_present:
                 s = set()
                 d[v] = s
                 s.add(oid)
+            # Register the object into subkey-value dictionaries
             for s in present:
                 s.add(oid)
         else:
@@ -832,42 +844,6 @@ class Memoize2(object):
         return res
 
 
-def gzipped(f):
-    """
-    Decorator to ZIP the response
-    """
-    @functools.wraps(f)
-    def view_func(*args, **kwargs):
-        @after_this_request
-        def zipper(response):
-            accept_encoding = request.headers.get('Accept-Encoding', '')
-
-            if 'gzip' not in accept_encoding.lower():
-                return response
-
-            response.direct_passthrough = False
-
-            if (response.status_code < 200 or
-                response.status_code >= 300 or
-                'Content-Encoding' in response.headers):
-                return response
-            gzip_buffer = IO()
-            gzip_file = gzip.GzipFile(mode='wb',
-                                      fileobj=gzip_buffer)
-            gzip_file.write(response.data)
-            gzip_file.close()
-
-            response.data = gzip_buffer.getvalue()
-            response.headers['Content-Encoding'] = 'gzip'
-            response.headers['Vary'] = 'Accept-Encoding'
-            response.headers['Content-Length'] = len(response.data)
-
-            return response
-
-        return f(*args, **kwargs)
-
-    return view_func
-
 # #####################################################################################################################
 # >>>> MAPPING <<<<
 # #####################################################################################################################
@@ -1079,6 +1055,7 @@ def to_str(v):
 
 
 def wv_create_client_and_resource_name(location, wv_user=None, wv_password=None, wv_host_name=None):
+    import webdav.client as wc
     if not wv_host_name:
         wv_host_name = get_global_configuration_variable("FS_SERVER") \
             if get_global_configuration_variable("FS_SERVER") else "nextcloud.data.magic-nexus.eu"
@@ -1339,8 +1316,11 @@ def prepare_dataframe_after_external_read(ds, df, cmd_name):
                 cols.append(d.code)  # Exact case
                 if not d.is_measure:
                     dims.add(d.code)
-                    # Also, convert to string if it is numeric
-                    if df.dtypes[c] in [np.int64, np.float]:
+                    num_column = df.dtypes[c] in [np.int64, np.float]
+                    # NaN values in dimensions replaced by ""
+                    df[c] = df[c].fillna('')
+                    # Convert to string if it is numeric
+                    if num_column:
                         df[c] = df[c].astype(str)
                 break
         else:
@@ -1358,7 +1338,7 @@ def prepare_dataframe_after_external_read(ds, df, cmd_name):
     if len(tmp[0]) > 0:
         for i in np.nditer(tmp):
             issue = Issue(itype=IType.ERROR,
-                          description=f"Duplicated row '{i+2}' in the data of dataset '{ds.code}'.",
+                          description=f"Duplicated row '{i+2}' in the data of dataset '{ds.code}' with value: {df.iloc[i]}",
                           location=IssueLocation(sheet_name=cmd_name,
                                                  row=i+2, column=None))
             issues.append(issue)
